@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_CLOSEJOB_H
-#define KIMAP_CLOSEJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -67,4 +66,3 @@ protected:
 
 }
 
-#endif
